@@ -3,37 +3,45 @@ from __future__ import absolute_import
 import flask
 import logging
 import sys
+import inspect
 from flask import request, signals
 
 import stackifyapm
 import stackifyapm.instrumentation.control
 from stackifyapm.base import Client
 from stackifyapm.conf import constants
-from stackifyapm.conf import setup_logging
 from stackifyapm.contrib.flask.utils import get_data_from_request, get_data_from_response, get_data_from_exception
 from stackifyapm.utils.helper import get_stackify_header
 from stackifyapm.utils import build_name_with_http_method_prefix
 from stackifyapm.utils.disttracing import TraceParent
-from stackifyapm.utils.helper import get_rum_script_or_None
+from stackifyapm.utils.helper import can_insert_script
+from stackifyapm.utils.helper import get_rum_script_or_none
 from stackifyapm.handlers.exceptions import get_exception_context
 from stackifyapm.traces import execution_context
 
-logger = logging.getLogger("stackifyapm.errors.client")
+logger = logging.getLogger("stackifyapm.traces")
 
 
 def make_client(app, **defaults):
+    config = app.config.get("STACKIFY_APM", {})
+    defaults.update(app.config)
+
+    frame = inspect.stack()[-1]
+    module = inspect.getmodule(frame[0])
+    main_file = module.__file__.split('/')[-1].split('.')[0]
+
+    instrument_all_exclude = defaults.get('INSTRUMENT_ALL_EXCLUDE', "")
+    excludes = instrument_all_exclude and instrument_all_exclude.split(',') or []
+    excludes.append(main_file or 'app')
+    defaults["INSTRUMENT_ALL_EXCLUDE"] = ','.join(excludes)
+
+    if not app.config.get("BASE_DIR"):
+        defaults["BASE_DIR"] = app.config.root_path
+
     if "framework_name" not in defaults:
         defaults["framework_name"] = "flask"
         defaults["framework_version"] = getattr(flask, "__version__", "<0.7")
 
-    config = {
-        "ENVIRONMENT": app.config.get("ENVIRONMENT") or app.config.get("ENV") or 'Production',
-        "APPLICATION_NAME": app.config.get("APPLICATION_NAME") or 'Python Application',
-        "BASE_DIR": app.config.get("BASE_DIR") or app.config.root_path,
-        "CONFIG_FILE": app.config.get("CONFIG_FILE") or constants.DEFAULT_CONFIG_FILE,
-        "MULTIPROCESSING": app.config.get("MULTIPROCESSING") or False,
-    }
-
     return Client(config, **defaults)
 
 
@@ -51,11 +59,10 @@ class StackifyAPM(object):
 
     def init_app(self, app, **defaults):
         self.app = app
+
         if not self.client:
             self.client = make_client(app, **defaults)
 
-        setup_logging(self.client)
-
         signals.got_request_exception.connect(self.handle_exception, sender=app, weak=False)
 
         try:
@@ -83,8 +90,11 @@ class StackifyAPM(object):
 
         @app.context_processor
         def rum_tracing():
+            if self.client.config.rum_auto_injection:
+                return {}
+
             transaction = execution_context.get_transaction()
-            rum_script = get_rum_script_or_None(transaction)
+            rum_script = get_rum_script_or_none(transaction)
             if rum_script:
                 return {
                     "stackifyapm_inject_rum": rum_script
@@ -105,17 +115,34 @@ class StackifyAPM(object):
         rule = request.url_rule.rule if request.url_rule is not None else ""
         rule = build_name_with_http_method_prefix(rule, request)
         stackifyapm.set_transaction_context(
-            lambda: get_data_from_request(
-                request, capture_body=self.client.config.capture_body in ("transactions", "all")
-            ),
+            lambda: get_data_from_request(request, capture_body=self.client.config.prefix_enabled),
             "request",
         )
-        stackifyapm.set_transaction_context(lambda: get_data_from_response(response), "response")
+        stackifyapm.set_transaction_context(
+            lambda: get_data_from_response(response, capture_body=self.client.config.prefix_enabled),
+            "response"
+        )
         stackifyapm.set_transaction_name(rule, override=False)
-        self.client.end_transaction()
 
         response.headers["X-StackifyID"] = get_stackify_header(transaction)
 
+        if self.client.config.rum_enabled:
+            stackifyapm.set_transaction_context(lambda: True, "rum")
+            # adding RUM Cookie
+            response.set_cookie(
+                constants.RUM_COOKIE_NAME,
+                str(transaction.get_trace_parent().trace_id),
+            )
+
+        if self.client.config.rum_auto_injection:
+            rum_script = get_rum_script_or_none(transaction)
+            data = response.get_data()
+            if rum_script and can_insert_script(data):
+                data = data.replace(str.encode('</head>'), str.encode('{}</head>'.format(rum_script)))
+                response.set_data(data)
+
+        self.client.end_transaction()
+
     def handle_exception(self, app, **kwargs):
         if not self.client:
             return
@@ -130,9 +157,7 @@ class StackifyAPM(object):
         rule = request.url_rule.rule if request.url_rule is not None else ""
         rule = build_name_with_http_method_prefix(rule, request)
         stackifyapm.set_transaction_context(
-            lambda: get_data_from_request(
-                request, capture_body=self.client.config.capture_body in ("transactions", "all")
-            ),
+            lambda: get_data_from_request(request, capture_body=self.client.config.prefix_enabled),
             "request",
         )
         stackifyapm.set_transaction_context(lambda: get_data_from_exception(), "response")
