@@ -1,3 +1,5 @@
+from stackifyapm.exceptions import StackifyAPMException
+from stackifyapm.instrumentation.decorators import call_exception_handler
 from stackifyapm.instrumentation.packages.base import AbstractInstrumentedModule
 from stackifyapm.traces import CaptureSpan
 from stackifyapm.utils import compat, get_method_name
@@ -34,20 +36,25 @@ class PythonMemcachedInstrumentation(AbstractInstrumentedModule):
         method_list += [("pymemcache.client.base", "Client.{}".format(method)) for method in self.memcached_method_list]
         return method_list
 
+    @call_exception_handler
     def call(self, module, method, wrapped, instance, args, kwargs):
-        method_name = get_method_name(method)
-        extra_data = {
-            "wrapped_method": "execute",
-            "provider": self.name,
-            "type": "Cache",
-            "sub_type": "cache",
-            "operation": method_name,
-        }
-        cache_name = args and args[0] or None
-        if isinstance(cache_name, compat.binary_type):
-            extra_data['cache_key'] = cache_name.decode('utf-8')
-        elif cache_name:
-            extra_data['cache_key'] = str(cache_name)
+        try:
+            method_name = get_method_name(method)
+            context = {
+                "CATEGORY": "Cache",
+                "SUBCATEGORY": "Execute",
+                "COMPONENT_CATEGORY": "Cache",
+                "COMPONENT_DETAIL": "Execute",
+                "OPERATION": method_name,
+            }
 
-        with CaptureSpan("cache.memcached", extra_data, is_async=is_async_span()):
+            cache_name = args and args[0] or None
+            if isinstance(cache_name, compat.binary_type):
+                context["CACHEKEY"] = cache_name.decode('utf-8')
+            elif cache_name:
+                context["CACHEKEY"] = str(cache_name)
+        except Exception as e:
+            raise StackifyAPMException(e)
+
+        with CaptureSpan("cache.memcached", context, is_async=is_async_span()):
             return wrapped(*args, **kwargs)
