@@ -1,5 +1,7 @@
 import uuid
 
+from stackifyapm.exceptions import StackifyAPMException
+from stackifyapm.instrumentation.decorators import call_exception_handler
 from stackifyapm.instrumentation.packages.base import AbstractInstrumentedModule
 from stackifyapm.traces import CaptureSpan
 from stackifyapm.traces import execution_context
@@ -17,20 +19,24 @@ class StackifyInstrumentation(AbstractInstrumentedModule):
     # which is the first argument of args
     instrument_list = [("stackify.handler", "StackifyHandler.enqueue")]
 
+    @call_exception_handler
     def call(self, module, method, wrapped, instance, args, kwargs):
-        log_id = str(uuid.uuid4())
-        if args:
-            args[0].log_id = log_id
+        try:
+            log_id = str(uuid.uuid4())
+            if args:
+                args[0].log_id = log_id
 
-            transaction = execution_context.get_transaction()
-            if transaction:
-                args[0].trans_id = transaction.get_id()
+                transaction = execution_context.get_transaction()
+                if transaction:
+                    args[0].trans_id = transaction.get_id()
 
-        extra_data = {
-            "type": "Stackify",
-            "wrapped_method": "log",
-            "log_id": log_id,
-        }
+            context = {
+                'CATEGORY': 'Stackify',
+                'SUBCATEGORY': 'Log',
+                'ID': log_id,
+            }
+        except Exception as e:
+            raise StackifyAPMException(e)
 
-        with CaptureSpan("stackify.log", extra_data, leaf=True, is_async=is_async_span()):
+        with CaptureSpan("stackify.log", context, leaf=True, is_async=is_async_span()):
             return wrapped(*args, **kwargs)
