@@ -35,6 +35,9 @@ _cls_registers = {
 
     # stackify log api instrumentation
     "stackifyapm.instrumentation.packages.stackify.StackifyInstrumentation",
+
+    # prefix logging instrumentation
+    "stackifyapm.instrumentation.packages.logger.LoggerInstrumentation",
 }
 
 
@@ -45,8 +48,10 @@ def register(cls):
 _instrumentation_singletons = {}
 
 
-def get_instrumentation_objects():
+def get_instrumentation_objects(client=None):
     for cls_str in _cls_registers:
+        if client and not client.config.prefix_enabled and 'Logger' in cls_str:
+            continue
         if cls_str not in _instrumentation_singletons:
             cls = import_string(cls_str)
             _instrumentation_singletons[cls_str] = cls()
