@@ -12,6 +12,7 @@ from stackifyapm.conf import constants
 from stackifyapm.conf.constants import ASYNC_WAITING_TIME_IN_SEC
 from stackifyapm.conf.constants import TRACE_CONTEXT_VERSION
 from stackifyapm.context import init_execution_context
+from stackifyapm.exceptions import StackifyAPMException
 from stackifyapm.utils import encoding
 from stackifyapm.utils import get_class_name_or_None
 from stackifyapm.utils import get_method_name
@@ -25,24 +26,6 @@ __all__ = ("CaptureSpan", "set_transaction_name")
 
 logger = logging.getLogger("stackifyapm.traces")
 error_logger = logging.getLogger("stackifyapm.errors")
-
-_COMPONENT_CATEGORY_MAP = {
-    "database_connect": "Database",
-    "database_sql": "DB Query",
-    "send": "Web External",
-    "cache": "Cache",
-    "template": "Template",
-}
-
-_COMPONENT_DETAIL_MAP = {
-    "database_connect": "Open Connection",
-    "database_sql": "Execute SQL Query",
-    "send": "Execute",
-    "cache": "Execute",
-    "template": "Template",
-}
-
-
 execution_context = init_execution_context()
 
 
@@ -136,7 +119,7 @@ class Transaction(object):
             else:
                 logger.warning("Can't find span id: {} from transaction id: {}".format(span_id, self.id))
         except Exception as e:
-            error_logger.error("Update span context error: {}.".format(e))
+            raise StackifyAPMException("Update span context error: {}.".format(e))
 
     def end_span(self):
         span = execution_context.get_span()
@@ -155,9 +138,9 @@ class Transaction(object):
     def is_done(self):
         return all([span.end_time for span in self.spans])
 
-    def get_stacks(self):
+    def get_stacks(self, config=None):
         stacks = []
-        spans = [span.to_dict() for span in self.spans]
+        spans = [span.to_dict(config=config) for span in self.spans]
         spans.reverse()
 
         # convert to key-value pair for easy access
@@ -172,14 +155,14 @@ class Transaction(object):
 
         return stacks
 
-    def to_dict(self):
+    def to_dict(self, config=None):
         result = {
             "id": self.id,
             "call": self._get_call(),
             "reqBegin": self.start_time,
             "reqEnd": self.end_time,
             "props": self._get_props(),
-            "stacks": self.get_stacks(),
+            "stacks": self.get_stacks(config=config),
         }
         if self.trace_parent.span_id and self.trace_parent.span_id != self.id:
             result["parent_id"] = self.trace_parent.span_id
@@ -291,7 +274,7 @@ class Span(object):
         self.id = "{}".format(len(transaction.get_spans()) + 1)
         self.transaction = transaction
         self.type = span_type
-        self.context = context
+        self.context = self._build_context(context)
         self.leaf = leaf
         self.parent = None
         self.start_time = get_current_time_in_millis()
@@ -299,7 +282,10 @@ class Span(object):
         self.is_async = is_async
         self._thread_id = str(threading.current_thread().ident)
 
-    def to_dict(self):
+    def _build_context(self, context):
+        return {k.upper(): v for k, v in iteritems(context)}
+
+    def to_dict(self, config=None):
         return {
             "id": self.id,
             "transaction_id": self.transaction.get_id(),
@@ -307,119 +293,26 @@ class Span(object):
             "call": encoding.keyword_field(self.type),
             "reqBegin": self.start_time,
             "reqEnd": self.end_time,
-            "props": self._get_props(),
+            "props": self._get_props(config=config),
             "stacks": [],
         }
 
-    def _get_props(self):
-        base_object = {
-            "CATEGORY": self._get_category(),
-        }
+    def _get_props(self, config=None):
+        self.context["CATEGORY"] = self.context.get("CATEGORY") or "Python"
 
-        if self.type.split('.')[0].lower() not in ["custom"]:
-            base_object["SUBCATEGORY"] = self._get_sub_catergory()
+        if "SQL" in self.context:
+            if len(self.context["SQL"]) > constants.SQL_STATEMENT_MAX_LENGTH:
+                self.context["SQL"] = self.context["SQL"][:constants.SQL_STATEMENT_MAX_LENGTH]
+                self.context["SQL_TRUNCATED"] = True
+
+        if "SQL_PARAMETERS" in self.context and (not config or not config.prefix_enabled):
+            self.context.pop("SQL_PARAMETERS")
 
         if self.is_async:
-            base_object["TRACETYPE"] = "ASYNC"
-            base_object["THREAD_ID"] = self._thread_id
+            self.context["TRACETYPE"] = "ASYNC"
+            self.context["THREAD_ID"] = self._thread_id
 
-        if not self.context:
-            return base_object
-
-        if self.context.get("type", "").lower() not in ["cassandra", "stackify", "log"] and self.type.split('.')[0].lower() not in ["custom"]:
-            base_object["COMPONENT_CATEGORY"] = self._get_component_category()
-            base_object["COMPONENT_DETAIL"] = self._get_component_detail()
-
-        if self.context.get("type", "").lower() in ["database", "mongodb"] and "provider" in self.context:
-            base_object["PROVIDER"] = self.context["provider"]
-
-        if self.context.get("type", "").lower() in ["database", "cassandra"]:
-            if "statement" in self.context:
-                if len(self.context["statement"]) > constants.SQL_STATEMENT_MAX_LENGTH:
-                    base_object["SQL"] = self.context["statement"][:constants.SQL_STATEMENT_MAX_LENGTH]
-                    base_object["SQL_TRUNCATED"] = True
-                else:
-                    base_object["SQL"] = self.context["statement"]
-
-        if self.context.get("type", "").lower() == "mongodb":
-            if "collection" in self.context:
-                base_object["MONGODB_COLLECTION"] = self.context["collection"]
-
-        if "url" in self.context:
-            base_object["URL"] = self.context["url"]
-
-        if "status_code" in self.context:
-            base_object["STATUS"] = str(self.context["status_code"])
-
-        if "request_method" in self.context:
-            base_object["METHOD"] = self.context["request_method"].upper()
-
-        if "operation" in self.context:
-            base_object["OPERATION"] = self.context["operation"]
-
-        if "cache_key" in self.context:
-            base_object["CACHEKEY"] = self.context["cache_key"]
-
-        if "cache_name" in self.context:
-            base_object["CACHENAME"] = self.context["cache_name"]
-
-        if "row_count" in self.context:
-            base_object["ROW_COUNT"] = self.context["row_count"]
-
-        if self.context.get("template"):
-            base_object["TEMPLATE"] = self.context["template"]
-
-        if self.type.split('.')[0].lower() in ["custom"]:
-            for k, v in iteritems(self.context):
-                if k not in ['type', 'sub_type', 'wrapped_method', 'provider']:
-                    base_object[k.upper()] = v
-
-        # for trace/log integration
-        # we will add log_id which was generated in the stackify instrumentation
-        if self.context.get("log_id"):
-            base_object["ID"] = self.context["log_id"]
-
-        if "request_body" in self.context:
-            base_object["REQUEST_BODY"] = str(self.context["request_body"])
-            base_object["REQUEST_SIZE_BYTES"] = str(self.context["request_body_size"])
-
-        if "request_headers" in self.context:
-            base_object["REQUEST_HEADERS"] = str(self.context["request_headers"])
-
-        if "response_body" in self.context:
-            base_object["RESPONSE_BODY"] = str(self.context["response_body"])
-            base_object["RESPONSE_SIZE_BYTES"] = str(self.context["response_body_size"])
-
-        if "response_headers" in self.context:
-            base_object["RESPONSE_HEADERS"] = str(self.context["response_headers"])
-
-        # Logger
-        if "level" in self.context:
-            base_object["LEVEL"] = str(self.context["level"])
-
-        if "message" in self.context:
-            base_object["MESSAGE"] = str(self.context["message"])
-
-        if "exception" in self.context:
-            base_object["EXCEPTION"] = str(self.context["exception"])
-
-        return base_object
-
-    def _get_category(self):
-        type = encoding.keyword_field(self.type)
-        return self.context and self.context.get("type", "") or type.split('.')[0].title()
-
-    def _get_sub_catergory(self):
-        wrapped_method = self.context and self.context.get("wrapped_method")
-        return wrapped_method and wrapped_method.title() or self._get_category()
-
-    def _get_component_category(self):
-        sub_type = self.context and self.context.get("sub_type", "") or ""
-        return _COMPONENT_CATEGORY_MAP.get(sub_type) or self._get_category() or "Python"
-
-    def _get_component_detail(self):
-        sub_type = self.context and self.context.get("sub_type") or ""
-        return _COMPONENT_DETAIL_MAP.get(sub_type) or self._get_sub_catergory() or "Other"
+        return self.context
 
 
 class DroppedSpan(object):
@@ -535,7 +428,7 @@ class CaptureSpan(object):
             if transaction and transaction.get_is_sampled():
                 return transaction.begin_span(self.type, context=self.extra, leaf=self.leaf, is_async=self.is_async)
         except Exception as e:
-            error_logger.error('Start span error: {}'.format(e))
+            raise StackifyAPMException('Start span error: {}'.format(e))
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         try:
@@ -546,7 +439,7 @@ class CaptureSpan(object):
                 except LookupError:
                     error_logger.info("ended non-existing span {} of type {}".format(self.name, self.type))
         except Exception as e:
-            error_logger.error('End span error: {}'.format(e))
+            raise StackifyAPMException('End span error: {}'.format(e))
 
 
 def set_transaction_name(name, override=True):
