@@ -57,7 +57,8 @@ class LoggingTransport(BaseTransport):
 
     def log_transaction(self, transaction):
         # log transaction immediately
-        json_string_trace = json.dumps(transaction.to_dict())
+        config = self._client and self._client.config or None
+        json_string_trace = json.dumps(transaction.to_dict(config=config))
         compressed_data = compress(json_string_trace)
         if self._client.config.lambda_handler:
             self.logging.debug(compressed_data)
