@@ -1,6 +1,6 @@
 import logging
 
-logger = logging.getLogger("stackifyapm.utils")
+logger = logging.getLogger("stackifyapm.traces")
 
 
 class TraceParent(object):
