@@ -84,6 +84,25 @@ class GenericIntegrationTest(TestCase):
         finally:
             os.remove(STACKIFY_JSON_FILE)
 
+    @mock.patch('stackifyapm.base.Client.queue')
+    def test_generic_apm_decorator(self, mock_queue):
+
+        @StackifyAPM(**CONFIG_FILE)
+        def test_function():
+            pass
+
+        test_function()
+
+        assert mock_queue.called
+
+        transaction_dict = mock_queue.call_args_list[0][0][0].to_dict()
+
+        assert transaction_dict['call'] == 'test_function'
+        assert transaction_dict['props']['REPORTING_URL'] == 'test_function'
+        assert transaction_dict['props']['APPLICATION_NAME'] == 'sample_application'
+        assert transaction_dict['props']['APPLICATION_ENV'] == 'production'
+        assert transaction_dict['props']['TRACETYPE'] == 'TASK'
+
     def test_basic_instrumentation(self):
         register._cls_registers = {
             "stackifyapm.instrumentation.packages.zlib.ZLibInstrumentation",
