@@ -4,7 +4,7 @@ from unittest import TestCase
 from stackifyapm.base import Client
 from stackifyapm.instrumentation import register
 from stackifyapm.instrumentation import control
-from stackifyapm.traces import get_transaction
+from stackifyapm.traces import execution_context
 
 CONFIG = {
     "SERVICE_NAME": "service_name",
@@ -44,7 +44,7 @@ class ZLibInstrumentationTest(TestCase):
         self.assert_span(operation='decompress')
 
     def assert_span(self, operation):
-        transaction = get_transaction()
+        transaction = execution_context.get_transaction()
         assert transaction
         assert transaction.get_spans()
 
